@@ -1,7 +1,6 @@
 from .handlers import RouteHandler
 from jupyter_server.extension.application import ExtensionApp
 from traitlets import Bool
-import json
 import pprint
 
 class ETCJupyterLabTelemetryLibraryApp(ExtensionApp):
@@ -11,6 +10,8 @@ class ETCJupyterLabTelemetryLibraryApp(ExtensionApp):
     load_other_extensions = True
     file_url_prefix = "/render"
 
+    notebook_clipboard_event = Bool(True).tag(config=True)
+    notebook_visibility_event = Bool(True).tag(config=True)
     notebook_save_event = Bool(True).tag(config=True)
     notebook_close_event = Bool(True).tag(config=True)
     notebook_open_event = Bool(True).tag(config=True)
